#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'moc-dw-main-window.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "libgui/src/moc-dw-main-window.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'moc-dw-main-window.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__dw_main_window_t {
    QByteArrayData data[14];
    char stringdata0[193];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__dw_main_window_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__dw_main_window_t qt_meta_stringdata_octave__dw_main_window = {
    {
QT_MOC_LITERAL(0, 0, 22), // "octave::dw_main_window"
QT_MOC_LITERAL(1, 23, 15), // "notice_settings"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 19), // "const gui_settings*"
QT_MOC_LITERAL(4, 60, 15), // "createPopupMenu"
QT_MOC_LITERAL(5, 76, 6), // "QMenu*"
QT_MOC_LITERAL(6, 83, 5), // "event"
QT_MOC_LITERAL(7, 89, 7), // "QEvent*"
QT_MOC_LITERAL(8, 97, 2), // "ev"
QT_MOC_LITERAL(9, 100, 13), // "request_close"
QT_MOC_LITERAL(10, 114, 17), // "request_close_all"
QT_MOC_LITERAL(11, 132, 19), // "request_close_other"
QT_MOC_LITERAL(12, 152, 19), // "request_switch_left"
QT_MOC_LITERAL(13, 172, 20) // "request_switch_right"

    },
    "octave::dw_main_window\0notice_settings\0"
    "\0const gui_settings*\0createPopupMenu\0"
    "QMenu*\0event\0QEvent*\0ev\0request_close\0"
    "request_close_all\0request_close_other\0"
    "request_switch_left\0request_switch_right"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__dw_main_window[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x0a /* Public */,
       4,    0,   57,    2, 0x09 /* Protected */,
       6,    1,   58,    2, 0x09 /* Protected */,
       9,    0,   61,    2, 0x08 /* Private */,
      10,    0,   62,    2, 0x08 /* Private */,
      11,    0,   63,    2, 0x08 /* Private */,
      12,    0,   64,    2, 0x08 /* Private */,
      13,    0,   65,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    0x80000000 | 5,
    QMetaType::Bool, 0x80000000 | 7,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::dw_main_window::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        dw_main_window *_t = static_cast<dw_main_window *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
        case 1: { QMenu* _r = _t->createPopupMenu();
            if (_a[0]) *reinterpret_cast< QMenu**>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->event((*reinterpret_cast< QEvent*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->request_close(); break;
        case 4: _t->request_close_all(); break;
        case 5: _t->request_close_other(); break;
        case 6: _t->request_switch_left(); break;
        case 7: _t->request_switch_right(); break;
        default: ;
        }
    }
}

const QMetaObject octave::dw_main_window::staticMetaObject = {
    { &QMainWindow::staticMetaObject, qt_meta_stringdata_octave__dw_main_window.data,
      qt_meta_data_octave__dw_main_window,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::dw_main_window::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::dw_main_window::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__dw_main_window.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int octave::dw_main_window::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
